@@ -51,6 +51,9 @@ c
         integer noOfFrag, noOfIntN, noOfNonIntN
 
         integer  i, n, j
+c///////////////
+c        integer cumev, cev
+c////////////
 c         /////
 c         real*8 sumerg
 
@@ -58,7 +61,9 @@ c         call ctestOnShell(' heavy bef frag', pj)
 c         sumerg = 0.
 c         ////
 
-
+c////////////
+c        call cqEventNo(cumev, cev)
+c//////////////////
         ntp=0
 c
 c            ** fragmentation with some nucleon interaction **
@@ -83,6 +88,8 @@ c                  Gheisha should be called directly
            noOfNuc = 0
            noOfInteNuc = 0
         else
+
+              
            call csampFragments(pj, ia, frga, noOfFragments,
      *       nuc, noOfNuc, noOfInteNuc)
            if(SkipPtclGen .eq. 0) then
@@ -98,8 +105,10 @@ c               make rotation
               call crot3mom( pj, a, ntp )
            endif
            call crot3mom( pj, nuc, noOfNuc) ! for all nucleons. see entry below
+
            call crot3mom( pj, frga, noOfFragments)
 
+
 c               move non-interacting nucleon and fragments
            do  i = 1, noOfNuc - noOfInteNuc 
               a(ntp+1) = nuc(i)
@@ -168,7 +177,7 @@ c        5) samples pt of fragments other than interacting nucleons
 c           and convert it to ptx, pty
 c
 c      noOfFragments:  # of heavy fragments stored in fra
-c      noOfNuc:       # of nucleons  stored innuc.
+c      noOfNuc:       # of nucleons  stored in nuc.
 c      noOfInteNuc:  # of interacting nucleons among them
 c
 c
@@ -195,7 +204,15 @@ c
          call cmakeFragTbl
          first = .false.
       endif
-c         
+
+      if( (pj.fm.p(4)-pj.mass)/pj.subcode .lt. 0.1) then
+         fra(1) = pj
+         noOfFragments = 1
+         noOfNuc = 0
+         noOfInteNuc = 0
+         return   !   ********
+      endif
+
 c
 c         get heavy group index from the incident charge  
       ihg=Charge2heavyG(pj.charge)
@@ -297,7 +314,8 @@ c           set interacting nuc. mom
       do   i=noOfNuc, noOfNuc - noOfInteNuc + 1, -1
          nuc(i).fm.p(1) = 0.
          nuc(i).fm.p(2) = 0.
-         nuc(i).fm.p(3) = sqrt(nuc(i).fm.p(4)**2 - nuc(i).mass**2)
+         nuc(i).fm.p(3) = sqrt(
+     *      max( nuc(i).fm.p(4)**2 - nuc(i).mass**2, 0.d0) )
       enddo
       end
 c     *****************************************************************
