@@ -429,8 +429,9 @@ c                                         kaon
          endif
       elseif(k0 .eq. knuc) then
 c                                        nucleon
-         rf=sqrt(sqrt(1.-xp))
-         if(u .gt. Ceneuc*rf) then
+c         rf=sqrt(sqrt(1.-xp))
+         rf=(1.-xp)**1.5
+         if(u .gt. Ceneuc*rf*3) then
 c              same charge
               p.charge = pj.charge
          else
