@@ -3,13 +3,14 @@ c	(->  ---------------------------------------------
 
         real*8  Cepic0  !2  Obsolute
         real*8  Cekaon  !2  Obsolute
-        integer SucInt  !2  The number of successive interactions inside A is affected by this parameter.
+        integer SucInt  !2  The number of successive interactions inside A is affected by this parameter.\newline
                         !   If $0\rightarrow$ old formula (before uv3.500) is used, which give rather         
-                        !   smaller number ($<Nsuc>$ in Air = 1.7 for 30 mb pp), if $1\rightarrow$ new one
-                        !   $<Nsuc>=2.2$ for 30 mb pp). Default is 0 (from V5.00 again).
+                        !   smaller number ($<Nsuc>$ in Air = 1.7 for 30 mb pp), \newline
+                        !   if $1\rightarrow$ new one $<Nsuc>=2.2$ for 30 mb pp). \newline
+                        !   Default is 0 (from V5.00 again).
         real*8  Ceneuc  !2 \verb| p -> n ; n-> p; p~->n~; n~->p~| prob.
-        real*8  Mudirp  !2 \verb| DD~| # enhancement factor. D is only for prompt muon.
-     	real*8  Kpilog  !2  K$_{ch}/\pi_{ch}=(Kpilog*log(ss+.069)+Kpicns)*exp(-8/s') where ss(GeV**2)= 
+        real*8  Mudirp  !2 \verb| DD~| \# enhancement factor. D is only for prompt muon.
+     	real*8  Kpilog  !2  K$_{ch}/\pi_{ch}$=(Kpilog*log(ss+.069)+Kpicns)*exp(-8/s') where ss(GeV**2)= 
                         !   effective s. s'(GeV**2)=s - 4.63.  See also Kpicns.
         real*8  Kpicns  !2  See Kpilog. 0.077
         real*8  Elund   !2   obsolete (from v6.0)
@@ -30,12 +31,19 @@ c                        !   Default is Elund.
 	real*8  Efermi  !2  If Kinetic E $<$ Efermi, Fermi Momentum is considered for Nucleus target.\\
 
         character*64  IntModel !1 Interaction model description. Usage was changed from v6.0. 
-                      !    One may list  code name and upper energy bound  for the code.
+                      !    One may list  code name and upper energy bound  for the code.\newline
                       ! E.g.  IntModel = '"dpmjet3"' ; to specify the dpmjet3 in the entire energy region
-                      !       IntModel = '"dpmjet3" 100 "nexus2" to specify dpmjet3 at < 100 GeV and nexus2 
-                      !        at E>100 GeV
+                      !       IntModel = '"dpmjet3" 100 "nexus2" to specify dpmjet3 at $<$ 100 GeV and nexus2 
+                      !        at E$>$100 GeV \newline
                       !       IntModel = '"nucrin" 5 "fritiof1.6" 500 "adhoc" to specify  Nucrin,
-                      !               fritiof1.6, and ad-hoc model in the respective energy region.
+                      !               fritiof1.6, and ad-hoc model in the respective energy region. This 
+                      !       corresponds to the old IntModel='int1'. \newline
+                      !       IntModel = '"nucrin" 5 "fritiof1.6" 10 "fritiof7.02"  and \newline
+                      !       IntModel = '"dpmjet3"' \newline
+                      !        are most promissing models that fit the observed 
+                      !       data (muons and gamma rays) for which the primary is well known by
+                      !       BESS and AMS observations ($<$ 100 GeV).
+
 c              next is old def.
 c        character*16  IntModel   !1 interaction model.  If 'int1', Lund Fritiof/Nucrin/adhoc models are used
 c                       ! for hadronic interactions.  If 'int2' Gheisha code is used for hadronic interactions,
