@@ -3,7 +3,7 @@ c         special purpose such as to see the scattering effect
 c         by putting  Es = 0.
 
        namelist  /HParam/
-     +  AnihiE, AtmosFile, BackAngLimit, BaseErg, BasePower
+     +  AnihiE, AtEnv, AtmosFile, BackAngLimit, BaseErg, BasePower
      +, BorderHeightH, BorderHeightL, Cekaon, Ceneuc, Cepic0
      +, Charge2heavyG, Code2heavyG, Code2massN, Deltkp, Deltpip, Deltpp
      +, DpmFile, Ecrit, Efermi, Elund, Elund2, Elund3, EndLevel
@@ -15,8 +15,8 @@ c         by putting  Es = 0.
      +, LpmPairEmin, LundPara, MagBrem, MagBremEmin, MagChgDist, MagD
      +, MagE, MagN, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE
      +, Moliere, MuBr, MuNI, MuPr, Mudirp, MulLow, NoOfSites2
-     +, OffsetHeight, PathLimit, PrevEventNo, PtAvFrag, PtAvNonInteNuc
-     +, RatioToE0, RecoilKineMinE, Reverse, SeedFileDev, SucInt, SucPw
-     +, TempDev, TraceDev, Truncc, Truncn, Truncx, UpsilonMin
-     +, UseRungeKutta, UserHookc, UserHooki, UserHookr, X0
-     +, XaxisFromSouth
+     +, OffsetHeight, PathLimit, PercentEnv, PrevEventNo, PtAvFrag
+     +, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse, SeedFileDev
+     +, SharpEnv, SucInt, SucPw, TempDev, TraceDev, Truncc, Truncn
+     +, Truncx, UpsilonMin, UseRungeKutta, UserHookc, UserHooki
+     +, UserHookr, X0, XaxisFromSouth
