@@ -242,7 +242,8 @@ c
       record /track/ incident ! input/outut.
 c             must have E, m, code, subcode, charge
       record /coord/ angle    ! input. must have direction cos in the det. sys.
-c
+      record /coord/ xyz
+c     
 c
       real*8 to100km, clenbetween2h, zenithcos, len
       integer i, j
@@ -313,9 +314,14 @@ c          set time 0
 
 
       do i = 1, NoOfSites
-         if( HeightOfInj .gt. ObsSites(i).pos.height ) then
-            incident.where = i
-            goto 222
+c               correction for Perpendicular : 2004/07/19
+         if( ObsPlane .eq. Perpendicular ) then
+c            fixing incident.where later.
+         elseif( ObsPlane .ne. NotUsed ) then
+            if( HeightOfInj .gt. ObsSites(i).pos.height ) then
+               incident.where = i
+               goto 222
+            endif
          endif
       enddo
       if(HeightOfInj .lt. BorderHeightL) then
@@ -327,27 +333,6 @@ c          set time 0
          call cerrorMsg('Injection height is > BorderHeightH',0)
       endif
 
-c           Next obs site
-c      if( Upgoing ) then
-ccc         incident.where = NoOfSites
-c         do i = NoOfSites, 1, -1
-c            if( HeightOfInj .lt. ObsSites(i).pos.height ) then
-c               incident.where = i
-c               goto 33
-c            endif
-c         enddo
-c         incident.where = 0
-c      else
-ccc         incident.where = 1     
-c         do i = 1, NoOfSites
-c            if( HeightOfInj .gt. ObsSites(i).pos.height ) then
-c               incident.where = i
-c               goto 33
-c            endif
-c         enddo
-c         incident.where = NoOfSites + 1
-c      endif
-c33   continue
 
       incident.asflag = 0
       incident.pos.colheight = Infty  ! latest nuc. collision height
@@ -387,6 +372,9 @@ c          compute min time from  the injection point to each
 c         obs level.
       if(ObsPlane .ne. spherical) then
          call csetMinTime(incident)
+         if(HeightOfInj .lt. BorderHeightL) then
+            call cerrorMsg('Injection height is < BorderHeightL',0)
+         endif
       endif
       end
       
