@@ -2,6 +2,8 @@ c       stacking tracking information
 c
       subroutine cpush(a)
       implicit none
+#include  "Zmaxdef.h"
+#include  "Ztrack.h"
 #include  "Zstackv.h"
       record /track/ a
       character*70  msg
@@ -23,7 +25,8 @@ c      endif
 c------------------------------------------------------------
       subroutine cpop(a, remain)
       implicit none
-
+#include  "Zmaxdef.h"
+#include  "Ztrack.h"
 #include  "Zstackv.h"
       record /track/ a
 
@@ -43,6 +46,8 @@ c---------------------------------------------------------
       subroutine cinitStack
 c         initialize stack.
       implicit none
+#include  "Zmaxdef.h"
+#include  "Ztrack.h"
 #include  "Zstackv.h"
       Stack_pos = 0
       end
