@@ -81,10 +81,10 @@ c -------------------------------------tracking a ptcl
 #include  "Zstackv.h"
 c                next is for DEBUG
 c//////
-c      logical deb
-c      common /cdebug/ deb
+      logical deb
+      common /cdebug/ deb
 c/////////
-cc      cc#define DEBUG 1
+#define DEBUG 0
 
 
       logical reset
@@ -94,7 +94,7 @@ cc      cc#define DEBUG 1
 cc      integer icon
 
 #if DEBUG == 1
-c      deb=.true.
+      deb=.true.
       call checkstat('before fixModel')
 #endif
 
@@ -225,7 +225,6 @@ c////////////
 c             call only for high energy particles
 c                  (at AS generation, some ptcl may have < KEminObs
 c                  or some may loose energy by dE/dx etc.
-
             call cobservation(2)
 
             if(Job .eq. 'newskel' .and.
@@ -251,14 +250,8 @@ c                where should be + 1 at flesh time
 c            &&&&& 
          endif
 c               update observation place
-         if(abs(ObsPlane) .eq. perpendicular) then
-            call cscalerProd(MovedTrack.vec.w, DcAtObsXyz,
-     *               cosangle)
-            if(cosangle .lt. 0.) then
-               MovedTrack.where = MovedTrack.where - 1
-            else
-               MovedTrack.where = MovedTrack.where + 1
-            endif
+c         if(abs(ObsPlane) .eq. perpendicular) then
+            MovedTrack.where = nextwhere
 c                  if more obs-site, stack current ptcl.
             if(.not. Upgoing) then ! incident is downgoing
                if(MovedTrack.where .gt. EndLevel) then
@@ -276,10 +269,10 @@ c                  if more obs-site, stack current ptcl.
                   call cpush(MovedTrack)
                endif
             endif
-         else
-            MovedTrack.where = nextwhere
-            call cpush(MovedTrack)
-         endif
+c        else
+c            MovedTrack.where = nextwhere
+c            call cpush(MovedTrack)
+c         endif
       elseif(MoveStat .eq. BorderL) then
          call cobservation(3)
       elseif(MoveStat .eq. BorderH) then
@@ -354,7 +347,7 @@ c      if(nc .gt. 750) then
             do i = 1, NumberOfInte
                write(*, *) ' process=',IntInfArray(i).process
                write(*, *) ' thickness=',IntInfArray(i).thickness
-               write(*, *) ' length=',IntInfArray(1).length
+               write(*, *) ' length=',IntInfArray(i).length
             enddo
             write(*,*)'  ProcessNo=', ProcessNo
             write(*,*)  '--------------'
@@ -400,11 +393,9 @@ c         argon
       endif
 
       if(HowGeomag .le. 2 .or. HowGeomag .eq. 31) then
-c             distant; change of B is < 1 % 
+c             distant; change of B is < 1 % (for default
+c             MagChgDist =20 km; you can change it)
          call clengSmallBC(TrackBefMove, distant)
-c   **********
-         distant = distant/10.
-c   **********
          if( (TrackBefMove.pos.xyz.r(1) - x)**2 + 
      *        (TrackBefMove.pos.xyz.r(2) - y)**2 + 
      *        (TrackBefMove.pos.xyz.r(3) - z)**2 
